@@ -314,7 +314,7 @@ pub struct Keys {
 /// # use meilisearch_sdk::{client::*, indexes::*, errors::Error};
 /// Version {
 ///    commit_sha: "b46889b5f0f2f8b91438a08a358ba8f05fc09fc1".to_string(),
-///    build_date: "2019-11-15T09:51:54.278247+00:00".to_string(),
+///    commit_date: "2019-11-15T09:51:54.278247+00:00".to_string(),
 ///    pkg_version: "0.1.1".to_string(),
 /// };
 /// ```
@@ -322,7 +322,7 @@ pub struct Keys {
 #[serde(rename_all = "camelCase")]
 pub struct Version {
     pub commit_sha: String,
-    pub build_date: String,
+    pub commit_date: String,
     pub pkg_version: String,
 }
 
